summaryrefslogtreecommitdiffstats
path: root/korganizer/kodaymatrix.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodaymatrix.h')
-rw-r--r--korganizer/kodaymatrix.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/korganizer/kodaymatrix.h b/korganizer/kodaymatrix.h
index a76e61874..60c2e3ced 100644
--- a/korganizer/kodaymatrix.h
+++ b/korganizer/kodaymatrix.h
@@ -29,10 +29,10 @@
#include <libkcal/incidencebase.h>
#include <libkcal/calendar.h>
-#include <qframe.h>
-#include <qcolor.h>
-#include <qtooltip.h>
-#include <qmap.h>
+#include <tqframe.h>
+#include <tqcolor.h>
+#include <tqtooltip.h>
+#include <tqmap.h>
class QDragEnterEvent;
class QDragMoveEvent;
@@ -61,7 +61,7 @@ class DynamicTip : public QToolTip
*
* @param parent the parent KODayMatrix control.
*/
- DynamicTip( QWidget *parent );
+ DynamicTip( TQWidget *parent );
protected:
/**
@@ -70,7 +70,7 @@ class DynamicTip : public QToolTip
*
* @param pos coordinates of the mouse.
*/
- void maybeTip( const QPoint &pos );
+ void maybeTip( const TQPoint &pos );
private:
/** the parent control this tooltip is designed for. */
@@ -102,7 +102,7 @@ class DynamicTip : public QToolTip
*
* @author Eitzenberger Thomas
*/
-class KODayMatrix: public QFrame, public KCal::Calendar::Observer
+class KODayMatrix: public TQFrame, public KCal::Calendar::Observer
{
Q_OBJECT
public:
@@ -112,7 +112,7 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
* Normally this should be a KDateNavigator
* @param name name of the widget
*/
- KODayMatrix( QWidget *parent, const char *name );
+ KODayMatrix( TQWidget *parent, const char *name );
/** destructor that deallocates all dynamically allocated private members.
*/
@@ -131,7 +131,7 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
* @param actdate recalculates the day matrix to show NUMDAYS starting from this
* date.
*/
- void updateView( const QDate &actdate );
+ void updateView( const TQDate &actdate );
/**
Update event states of dates. Depending of the preferences days with
@@ -139,15 +139,15 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
*/
void updateEvents();
/** returns the QDate object associated with day indexed by the
* supplied offset.
*/
- const QDate& getDate( int offset );
+ const TQDate& getDate( int offset );
/** returns the official name of this holy day or 0 if there is no label
* for this day.
*/
- QString getHolidayLabel( int offset );
+ TQString getHolidayLabel( int offset );
/** adds all actual selected days from mSelStart to mSelEnd to the supplied
* DateList.
@@ -158,7 +158,7 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
* start and ending with end. Theview must be manually updated by calling
* repaint. (?)
*/
- void setSelectedDaysFrom( const QDate &start, const QDate &end );
+ void setSelectedDaysFrom( const TQDate &start, const TQDate &end );
/**
Clear all selections.
@@ -212,34 +212,34 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
/** emitted if the user has dropped an incidence (event or todo) inside the matrix
*
* @param incidence the dropped calendar incidence
* @param dt QDate that has been selected
*/
- void incidenceDropped( Incidence *incidence, const QDate &dt );
+ void incidenceDropped( Incidence *incidence, const TQDate &dt );
/** emitted if the user has dropped an event inside the matrix and chose to move it instead of copy
*
* @param oldincidence the new calendar incidence
* @param dt QDate that has been selected
*/
- void incidenceDroppedMove( Incidence *oldincidence, const QDate &dt );
+ void incidenceDroppedMove( Incidence *oldincidence, const TQDate &dt );
protected:
- void paintEvent( QPaintEvent *ev );
+ void paintEvent( TQPaintEvent *ev );
- void mousePressEvent( QMouseEvent *e );
+ void mousePressEvent( TQMouseEvent *e );
- void mouseReleaseEvent( QMouseEvent *e );
+ void mouseReleaseEvent( TQMouseEvent *e );
- void mouseMoveEvent( QMouseEvent *e );
+ void mouseMoveEvent( TQMouseEvent *e );
- void dragEnterEvent( QDragEnterEvent * );
+ void dragEnterEvent( TQDragEnterEvent * );
- void dragMoveEvent( QDragMoveEvent * );
+ void dragMoveEvent( TQDragMoveEvent * );
- void dragLeaveEvent( QDragLeaveEvent * );
+ void dragLeaveEvent( TQDragLeaveEvent * );
- void dropEvent( QDropEvent * );
+ void dropEvent( TQDropEvent * );
- void resizeEvent( QResizeEvent * );
+ void resizeEvent( TQResizeEvent * );
private:
/** returns the index of the day located at the matrix's widget (x,y) position.
@@ -254,7 +254,7 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
*
* @param color source based on which a shaded color should be calculated.
*/
- QColor getShadedColor( const QColor &color );
+ TQColor getShadedColor( const TQColor &color );
/** number of days to be displayed. For now there is no support for any other number then 42.
so change it at your own risk :o) */
@@ -264,14 +264,14 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
Calendar *mCalendar;
/** starting date of the matrix */
- QDate mStartDate;
+ TQDate mStartDate;
/** array of day labels to optimeize drawing performance. */
- QString *mDayLabels;
+ TQString *mDayLabels;
/** array of days displayed to reduce memory consumption by
- subsequently calling QDate::addDays(). */
- QDate *mDays;
+ subsequently calling TQDate::addDays(). */
+ TQDate *mDays;
/** array of storing the number of events on a given day.
* used for drawing a bold font if there is at least one event on that day.
@@ -279,7 +279,7 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
int *mEvents;
/** stores holiday names of the days shown in the matrix. */
- QMap<int,QString> mHolidays;
+ TQMap<int,TQString> mHolidays;
/** index of today or -1 if today is not visible in the matrix. */
int mToday;
@@ -307,7 +307,7 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
/** stores actual size of each day in the widget so that I don't need to ask this data
* on every repaint.
*/
- QRect mDaySize;
+ TQRect mDaySize;
/**
* Indicate pending calendar changes.
@@ -139,15 +139,15 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
*/
void updateEvents();
- /** returns the QDate object associated with day indexed by the
+ /** returns the TQDate object associated with day indexed by the
* supplied offset.
*/
@@ -212,34 +212,34 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
*
* @param incidence the dropped calendar incidence
- * @param dt QDate that has been selected
+ * @param dt TQDate that has been selected
*/
@@ -212,34 +212,34 @@ class KODayMatrix: public QFrame, public KCal::Calendar::Observer
*
* @param oldincidence the new calendar incidence
- * @param dt QDate that has been selected
+ * @param dt TQDate that has been selected
*/